@@ -20,10 +20,9 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Bias.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "core/ActionSet.h"
 #include "core/PlumedMain.h"
-#include "core/Atoms.h"
 #include "core/FlexibleBin.h"
 #include "tools/Exception.h"
 #include "tools/Grid.h"
@@ -31,11 +30,9 @@
 #include "tools/OpenMP.h"
 #include "tools/Random.h"
 #include "tools/File.h"
+#include "tools/Communicator.h"
 #include <ctime>
 #include <numeric>
-#if defined(__PLUMED_HAS_GETCWD)
-#include <unistd.h>
-#endif
 
 namespace PLMD {
 namespace bias {
@@ -247,7 +244,12 @@ private:
     Gaussian(const std::vector<double> & center,const std::vector<double> & sigma, double height, bool multivariate):
       center(center),sigma(sigma),height(height),multivariate(multivariate),invsigma(sigma) {
       // to avoid troubles from zero element in flexible hills
-        for(unsigned i=0; i<invsigma.size(); ++i) if(std::abs(invsigma[i])>1.e-20) invsigma[i]=1.0/invsigma[i] ; else invsigma[i]=0.0;
+      for(unsigned i=0; i<invsigma.size(); ++i)
+        if(std::abs(invsigma[i])>1.e-20) {
+          invsigma[i]=1.0/invsigma[i] ;
+        } else {
+          invsigma[i]=0.0;
+        }
     }
   };
   // general setup
@@ -383,8 +385,7 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   pf_n_(0), do_pf_(false),
   mw_n_(1), mw_dir_(""), mw_id_(0), mw_rstride_(1),
   walkers_mpi_(false), mpi_nw_(0),
-  do_select_(false)
-{
+  do_select_(false) {
 
   // parse the flexible hills
   std::string adaptiveoption;
@@ -410,7 +411,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   std::vector<Value*> familyargs;
   for(int i = 0;; i++) {
     parseArgumentList("PF", i, familyargs);
-    if (familyargs.empty()) break;
+    if (familyargs.empty()) {
+      break;
+    }
 
     do_pf_ = true;
     log << "  Identified Partitioned Family " << i << ":";
@@ -449,7 +452,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   } else {
     // If we are doing PF, make sure each argument got assigned to a family.
     for (unsigned i = 0; i < getNumberOfArguments(); i++) {
-      if (pfs_[i] == -1) error(getPntrToArgument(i)->getName() + " was not assigned a PF");
+      if (pfs_[i] == -1) {
+        error(getPntrToArgument(i)->getName() + " was not assigned a PF");
+      }
     }
   }
 
@@ -478,7 +483,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       error("the number of SIGMA_MIN values be the same of the number of the arguments/PF");
     } else if(sigma0min_.size()==0) {
       sigma0min_.resize(pf_n_);
-      for(unsigned i=0; i<pf_n_; i++) {sigma0min_[i]=-1.;}
+      for(unsigned i=0; i<pf_n_; i++) {
+        sigma0min_[i]=-1.;
+      }
     }
 
     parseVector("SIGMA_MAX",sigma0max_);
@@ -486,7 +493,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       error("the number of SIGMA_MAX values be the same of the number of the arguments/PF");
     } else if(sigma0max_.size()==0) {
       sigma0max_.resize(pf_n_);
-      for(unsigned i=0; i<pf_n_; i++) {sigma0max_[i]=-1.;}
+      for(unsigned i=0; i<pf_n_; i++) {
+        sigma0max_[i]=-1.;
+      }
     }
 
     for(unsigned i=0; i<pf_n_; i++) {
@@ -500,7 +509,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   // note: HEIGHT is not compulsory, since one could use the TAU keyword, see below
   parse("HEIGHT",height0_);
   parse("PACE",stride_);
-  if(stride_<=0) error("frequency for hill addition is nonsensical");
+  if(stride_<=0) {
+    error("frequency for hill addition is nonsensical");
+  }
 
 
   parseVector("FILE",hillsfname_);
@@ -515,24 +526,33 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   }
 
   parse("BIASFACTOR",biasf_);
-  if( biasf_<1.0 ) error("well tempered bias factor is nonsensical");
-  double temp=0.0;
-  parse("TEMP",temp);
-  if(temp>0.0) kbt_=plumed.getAtoms().getKBoltzmann()*temp;
-  else kbt_=plumed.getAtoms().getKbT();
+  if( biasf_<1.0 ) {
+    error("well tempered bias factor is nonsensical");
+  }
+  kbt_=getkBT();
   if(biasf_>1.0) {
-    if(kbt_==0.0) error("Unless the MD engine passes the temperature to plumed, with well-tempered metad you must specify it using TEMP");
+    if(kbt_==0.0) {
+      error("Unless the MD engine passes the temperature to plumed, with well-tempered metad you must specify it using TEMP");
+    }
     welltemp_=true;
   }
   double tau=0.0;
   parse("TAU",tau);
   if(tau==0.0) {
-    if(height0_==std::numeric_limits<double>::max()) error("At least one between HEIGHT and TAU should be specified");
+    if(height0_==std::numeric_limits<double>::max()) {
+      error("At least one between HEIGHT and TAU should be specified");
+    }
     // if tau is not set, we compute it here from the other input parameters
-    if(welltemp_) tau=(kbt_*(biasf_-1.0))/height0_*getTimeStep()*stride_;
+    if(welltemp_) {
+      tau=(kbt_*(biasf_-1.0))/height0_*getTimeStep()*stride_;
+    }
   } else {
-    if(!welltemp_)error("TAU only makes sense in well-tempered metadynamics");
-    if(height0_!=std::numeric_limits<double>::max()) error("At most one between HEIGHT and TAU should be specified");
+    if(!welltemp_) {
+      error("TAU only makes sense in well-tempered metadynamics");
+    }
+    if(height0_!=std::numeric_limits<double>::max()) {
+      error("At most one between HEIGHT and TAU should be specified");
+    }
     height0_=(kbt_*(biasf_-1.0))/tau*getTimeStep()*stride_;
   }
 
@@ -540,7 +560,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   // Multiple walkers
   parse("WALKERS_N",mw_n_);
   parse("WALKERS_ID",mw_id_);
-  if(mw_n_<=mw_id_) error("walker ID should be a numerical value less than the total number of walkers");
+  if(mw_n_<=mw_id_) {
+    error("walker ID should be a numerical value less than the total number of walkers");
+  }
   parse("WALKERS_DIR",mw_dir_);
   parse("WALKERS_RSTRIDE",mw_rstride_);
 
@@ -560,8 +582,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       gridfilenames_.push_back(name);
     }
   }
-  if(gridfilenames_.size() > 0 && hillsfname_.size() > 0 && gridfilenames_.size() != hillsfname_.size())
+  if(gridfilenames_.size() > 0 && hillsfname_.size() > 0 && gridfilenames_.size() != hillsfname_.size()) {
     error("number of GRID_WFILES arguments does not match number of HILLS files");
+  }
 
   // Read grid
   std::vector<std::string> gridreadfilenames_;
@@ -570,32 +593,53 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   // Grid Stuff
   std::vector<std::string> gmin(pf_n_);
   parseVector("GRID_MIN",gmin);
-  if(gmin.size()!=pf_n_ && gmin.size()!=0) error("not enough values for GRID_MIN");
+  if(gmin.size()!=pf_n_ && gmin.size()!=0) {
+    error("not enough values for GRID_MIN");
+  }
   std::vector<std::string> gmax(pf_n_);
   parseVector("GRID_MAX",gmax);
-  if(gmax.size()!=pf_n_ && gmax.size()!=0) error("not enough values for GRID_MAX");
+  if(gmax.size()!=pf_n_ && gmax.size()!=0) {
+    error("not enough values for GRID_MAX");
+  }
   std::vector<unsigned> gbin(pf_n_);
   std::vector<double>   gspacing;
   parseVector("GRID_BIN",gbin);
-  if(gbin.size()!=pf_n_ && gbin.size()!=0) error("not enough values for GRID_BIN");
+  if(gbin.size()!=pf_n_ && gbin.size()!=0) {
+    error("not enough values for GRID_BIN");
+  }
   parseVector("GRID_SPACING",gspacing);
-  if(gspacing.size()!=pf_n_ && gspacing.size()!=0) error("not enough values for GRID_SPACING");
-  if(gmin.size()!=gmax.size()) error("GRID_MAX and GRID_MIN should be either present or absent");
-  if(gspacing.size()!=0 && gmin.size()==0) error("If GRID_SPACING is present also GRID_MIN and GRID_MAX should be present");
-  if(gbin.size()!=0     && gmin.size()==0) error("If GRID_BIN is present also GRID_MIN and GRID_MAX should be present");
+  if(gspacing.size()!=pf_n_ && gspacing.size()!=0) {
+    error("not enough values for GRID_SPACING");
+  }
+  if(gmin.size()!=gmax.size()) {
+    error("GRID_MAX and GRID_MIN should be either present or absent");
+  }
+  if(gspacing.size()!=0 && gmin.size()==0) {
+    error("If GRID_SPACING is present also GRID_MIN and GRID_MAX should be present");
+  }
+  if(gbin.size()!=0     && gmin.size()==0) {
+    error("If GRID_BIN is present also GRID_MIN and GRID_MAX should be present");
+  }
   if(gmin.size()!=0) {
     if(gbin.size()==0 && gspacing.size()==0) {
       if(adaptive_==FlexibleBin::none) {
         log<<"  Binsize not specified, 1/5 of sigma will be be used\n";
         plumed_assert(sigma0_.size()==pf_n_);
         gspacing.resize(pf_n_);
-        for(unsigned i=0; i<gspacing.size(); i++) gspacing[i]=0.2*sigma0_[i];
+        for(unsigned i=0; i<gspacing.size(); i++) {
+          gspacing[i]=0.2*sigma0_[i];
+        }
       } else {
         // with adaptive hills and grid a sigma min must be specified
-        for(unsigned i=0; i<sigma0min_.size(); i++) if(sigma0min_[i]<=0) error("When using ADAPTIVE Gaussians on a grid SIGMA_MIN must be specified");
+        for(unsigned i=0; i<sigma0min_.size(); i++)
+          if(sigma0min_[i]<=0) {
+            error("When using ADAPTIVE Gaussians on a grid SIGMA_MIN must be specified");
+          }
         log<<"  Binsize not specified, 1/5 of sigma_min will be be used\n";
         gspacing.resize(pf_n_);
-        for(unsigned i=0; i<gspacing.size(); i++) gspacing[i]=0.2*sigma0min_[i];
+        for(unsigned i=0; i<gspacing.size(); i++) {
+          gspacing[i]=0.2*sigma0min_[i];
+        }
       }
     } else if(gspacing.size()!=0 && gbin.size()==0) {
       log<<"  The number of bins will be estimated from GRID_SPACING\n";
@@ -603,36 +647,56 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       log<<"  You specified both GRID_BIN and GRID_SPACING\n";
       log<<"  The more conservative (highest) number of bins will be used for each variable\n";
     }
-    if(gbin.size()==0) gbin.assign(pf_n_,1);
-    if(gspacing.size()!=0) for(unsigned i=0; i<pf_n_; i++) {
+    if(gbin.size()==0) {
+      gbin.assign(pf_n_,1);
+    }
+    if(gspacing.size()!=0)
+      for(unsigned i=0; i<pf_n_; i++) {
         double a,b;
         Tools::convert(gmin[i],a);
         Tools::convert(gmax[i],b);
         unsigned n=std::ceil(((b-a)/gspacing[i]));
-        if(gbin[i]<n) gbin[i]=n;
+        if(gbin[i]<n) {
+          gbin[i]=n;
+        }
       }
   }
-  if(gbin.size()>0) grid_=true;
+  if(gbin.size()>0) {
+    grid_=true;
+  }
 
   bool sparsegrid=false;
   parseFlag("GRID_SPARSE",sparsegrid);
   bool nospline=false;
   parseFlag("GRID_NOSPLINE",nospline);
   bool spline=!nospline;
-  if(!grid_&&gridfilenames_.size() > 0) error("To write a grid you need first to define it!");
-  if(!grid_&&gridreadfilenames_.size() > 0) error("To read a grid you need first to define it!");
+  if(!grid_&&gridfilenames_.size() > 0) {
+    error("To write a grid you need first to define it!");
+  }
+  if(!grid_&&gridreadfilenames_.size() > 0) {
+    error("To read a grid you need first to define it!");
+  }
 
   doInt_.resize(pf_n_,false);
   // Interval keyword
   parseVector("INTERVAL_MIN",lowI_);
   parseVector("INTERVAL_MAX",uppI_);
   // various checks
-  if(lowI_.size()!=uppI_.size()) error("both a lower and an upper limits must be provided with INTERVAL");
-  if(lowI_.size()!=0 && lowI_.size()!=pf_n_) error("check number of argument of INTERVAL");
+  if(lowI_.size()!=uppI_.size()) {
+    error("both a lower and an upper limits must be provided with INTERVAL");
+  }
+  if(lowI_.size()!=0 && lowI_.size()!=pf_n_) {
+    error("check number of argument of INTERVAL");
+  }
   for(unsigned i=0; i<lowI_.size(); ++i) {
-    if(uppI_[i]<lowI_[i]) error("The Upper limit must be greater than the Lower limit!");
-    if(pfhold_[i]->isPeriodic()) warning("INTERVAL is not used for periodic variables");
-    else doInt_[i]=true;
+    if(uppI_[i]<lowI_[i]) {
+      error("The Upper limit must be greater than the Lower limit!");
+    }
+    if(pfhold_[i]->isPeriodic()) {
+      warning("INTERVAL is not used for periodic variables");
+    } else {
+      doInt_[i]=true;
+    }
   }
 
   // parse selector stuff
@@ -646,13 +710,21 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   checkRead();
 
   log.printf("  Gaussian width ");
-  if (adaptive_==FlexibleBin::diffusion)log.printf(" (Note: The units of sigma are in timesteps) ");
-  if (adaptive_==FlexibleBin::geometry)log.printf(" (Note: The units of sigma are in dist units) ");
-  for(unsigned i=0; i<sigma0_.size(); ++i) log.printf(" %f",sigma0_[i]);
+  if (adaptive_==FlexibleBin::diffusion) {
+    log.printf(" (Note: The units of sigma are in timesteps) ");
+  }
+  if (adaptive_==FlexibleBin::geometry) {
+    log.printf(" (Note: The units of sigma are in dist units) ");
+  }
+  for(unsigned i=0; i<sigma0_.size(); ++i) {
+    log.printf(" %f",sigma0_[i]);
+  }
   log.printf("  Gaussian height %f\n",height0_);
   log.printf("  Gaussian deposition pace %d\n",stride_);
   log.printf("  Gaussian files ");
-  for(unsigned i=0; i<hillsfname_.size(); ++i) log.printf("%s ",hillsfname_[i].c_str());
+  for(unsigned i=0; i<hillsfname_.size(); ++i) {
+    log.printf("%s ",hillsfname_[i].c_str());
+  }
   log.printf("\n");
   if(welltemp_) {
     log.printf("  Well-Tempered Bias Factor %f\n",biasf_);
@@ -666,15 +738,21 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   }
 
   if(mw_n_>1) {
-    if(walkers_mpi_) error("MPI version of multiple walkers is not compatible with filesystem version of multiple walkers");
+    if(walkers_mpi_) {
+      error("MPI version of multiple walkers is not compatible with filesystem version of multiple walkers");
+    }
     log.printf("  %d multiple walkers active\n",mw_n_);
     log.printf("  walker id %d\n",mw_id_);
     log.printf("  reading stride %d\n",mw_rstride_);
-    if(mw_dir_!="")log.printf("  directory with hills files %s\n",mw_dir_.c_str());
+    if(mw_dir_!="") {
+      log.printf("  directory with hills files %s\n",mw_dir_.c_str());
+    }
   } else {
     if(walkers_mpi_) {
       log.printf("  Multiple walkers active using MPI communnication\n");
-      if(mw_dir_!="")log.printf("  directory with hills files %s\n",mw_dir_.c_str());
+      if(mw_dir_!="") {
+        log.printf("  directory with hills files %s\n",mw_dir_.c_str());
+      }
       if(comm.Get_rank()==0) {
         // Only root of group can communicate with other walkers
         mpi_nw_ = multi_sim_comm.Get_size();
@@ -688,20 +766,32 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   }
 
   for(unsigned i=0; i<doInt_.size(); i++) {
-    if(doInt_[i]) log.printf("  Upper and Lower limits boundaries for the bias of CV %u are activated\n", i);
+    if(doInt_[i]) {
+      log.printf("  Upper and Lower limits boundaries for the bias of CV %u are activated\n", i);
+    }
   }
   if(grid_) {
     log.printf("  Grid min");
-    for(unsigned i=0; i<gmin.size(); ++i) log.printf(" %s",gmin[i].c_str() );
+    for(unsigned i=0; i<gmin.size(); ++i) {
+      log.printf(" %s",gmin[i].c_str() );
+    }
     log.printf("\n");
     log.printf("  Grid max");
-    for(unsigned i=0; i<gmax.size(); ++i) log.printf(" %s",gmax[i].c_str() );
+    for(unsigned i=0; i<gmax.size(); ++i) {
+      log.printf(" %s",gmax[i].c_str() );
+    }
     log.printf("\n");
     log.printf("  Grid bin");
-    for(unsigned i=0; i<gbin.size(); ++i) log.printf(" %u",gbin[i]);
+    for(unsigned i=0; i<gbin.size(); ++i) {
+      log.printf(" %u",gbin[i]);
+    }
     log.printf("\n");
-    if(spline) {log.printf("  Grid uses spline interpolation\n");}
-    if(sparsegrid) {log.printf("  Grid uses sparse grid\n");}
+    if(spline) {
+      log.printf("  Grid uses spline interpolation\n");
+    }
+    if(sparsegrid) {
+      log.printf("  Grid uses sparse grid\n");
+    }
     if(wgridstride_>0) {
       for(unsigned i=0; i<gridfilenames_.size(); ++i) {
         log.printf("  Grid is written on file %s with stride %d\n",gridfilenames_[i].c_str(),wgridstride_);
@@ -730,9 +820,13 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       Tools::convert(gmax[family],b);
       double mesh=(b-a)/((double)gbin[family]);
       if(adaptive_==FlexibleBin::none) {
-        if(mesh>0.5*sigma0_[i]) log<<"  WARNING: Using a PBMETAD with a Grid Spacing larger than half of the Gaussians width can produce artifacts\n";
+        if(mesh>0.5*sigma0_[i]) {
+          log<<"  WARNING: Using a PBMETAD with a Grid Spacing larger than half of the Gaussians width can produce artifacts\n";
+        }
       } else {
-        if(mesh>0.5*sigma0min_[i]||sigma0min_[i]<0.) log<<"  WARNING: to use a PBMETAD with a GRID and ADAPTIVE you need to set a Grid Spacing larger than half of the Gaussians \n";
+        if(mesh>0.5*sigma0min_[i]||sigma0min_[i]<0.) {
+          log<<"  WARNING: to use a PBMETAD with a GRID and ADAPTIVE you need to set a Grid Spacing larger than half of the Gaussians \n";
+        }
       }
     }
     std::string funcl=getLabel() + ".bias";
@@ -764,16 +858,25 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
           error("periodicity mismatch between arguments and input bias");
         }
         log.printf("  Restarting from %s:\n",gridreadfilenames_[i].c_str());
-        if(getRestart()) restartedFromGrid=true;
+        if(getRestart()) {
+          restartedFromGrid=true;
+        }
       } else {
-        if(!sparsegrid) {BiasGrid_=Tools::make_unique<Grid>(funcl,args,gmin_t,gmax_t,gbin_t,spline,true);}
-        else           {BiasGrid_=Tools::make_unique<SparseGrid>(funcl,args,gmin_t,gmax_t,gbin_t,spline,true);}
+        if(!sparsegrid) {
+          BiasGrid_=Tools::make_unique<Grid>(funcl,args,gmin_t,gmax_t,gbin_t,spline,true);
+        } else           {
+          BiasGrid_=Tools::make_unique<SparseGrid>(funcl,args,gmin_t,gmax_t,gbin_t,spline,true);
+        }
         std::vector<std::string> actualmin=BiasGrid_->getMin();
         std::vector<std::string> actualmax=BiasGrid_->getMax();
         std::string is;
         Tools::convert(i,is);
-        if(gmin_t[0]!=actualmin[0]) error("GRID_MIN["+is+"] must be adjusted to "+actualmin[0]+" to fit periodicity");
-        if(gmax_t[0]!=actualmax[0]) error("GRID_MAX["+is+"] must be adjusted to "+actualmax[0]+" to fit periodicity");
+        if(gmin_t[0]!=actualmin[0]) {
+          error("GRID_MIN["+is+"] must be adjusted to "+actualmin[0]+" to fit periodicity");
+        }
+        if(gmax_t[0]!=actualmax[0]) {
+          error("GRID_MAX["+is+"] must be adjusted to "+actualmax[0]+" to fit periodicity");
+        }
       }
       BiasGrids_.emplace_back(std::move(BiasGrid_));
     }
@@ -790,7 +893,8 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       std::string fname;
       if(mw_dir_!="") {
         if(mw_n_>1) {
-          std::stringstream out; out << j;
+          std::stringstream out;
+          out << j;
           fname = mw_dir_+"/"+hillsfname_[i]+"."+out.str();
         } else if(walkers_mpi_) {
           fname = mw_dir_+"/"+hillsfname_[i];
@@ -799,7 +903,8 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
         }
       } else {
         if(mw_n_>1) {
-          std::stringstream out; out << j;
+          std::stringstream out;
+          out << j;
           fname = hillsfname_[i]+"."+out.str();
         } else {
           fname = hillsfname_[i];
@@ -818,16 +923,22 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
         }
         ifiles_[k]->reset(false);
         // close only the walker own hills file for later writing
-        if(j==mw_id_) ifiles_[k]->close();
+        if(j==mw_id_) {
+          ifiles_[k]->close();
+        }
       } else {
         // in case a file does not exist and we are restarting, complain that the file was not found
-        if(getRestart()) log<<"  WARNING: restart file "<<fname<<" not found\n";
+        if(getRestart()) {
+          log<<"  WARNING: restart file "<<fname<<" not found\n";
+        }
       }
     }
   }
 
   comm.Barrier();
-  if(comm.Get_rank()==0 && walkers_mpi_) multi_sim_comm.Barrier();
+  if(comm.Get_rank()==0 && walkers_mpi_) {
+    multi_sim_comm.Barrier();
+  }
 
   // open hills files for writing
   for(unsigned i=0; i<hillsfname_.size(); ++i) {
@@ -836,14 +947,22 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
     // if MPI multiple walkers, only rank 0 will write to file
     if(walkers_mpi_) {
       int r=0;
-      if(comm.Get_rank()==0) r=multi_sim_comm.Get_rank();
+      if(comm.Get_rank()==0) {
+        r=multi_sim_comm.Get_rank();
+      }
       comm.Bcast(r,0);
-      if(r>0) ifilesnames_[mw_id_*hillsfname_.size()+i]="/dev/null";
+      if(r>0) {
+        ifilesnames_[mw_id_*hillsfname_.size()+i]="/dev/null";
+      }
+      ofile->enforceSuffix("");
+    }
+    if(mw_n_>1) {
       ofile->enforceSuffix("");
     }
-    if(mw_n_>1) ofile->enforceSuffix("");
     ofile->open(ifilesnames_[mw_id_*hillsfname_.size()+i]);
-    if(fmt_.length()>0) ofile->fmtField(fmt_);
+    if(fmt_.length()>0) {
+      ofile->fmtField(fmt_);
+    }
     ofile->addConstantField("multivariate");
     ofile->addConstantField("kerneltype");
     if(doInt_[i]) {
@@ -874,7 +993,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
         }
         ofile->enforceSuffix("");
       }
-      if(mw_n_>1) ofile->enforceSuffix("");
+      if(mw_n_>1) {
+        ofile->enforceSuffix("");
+      }
       ofile->open(gridfname_tmp);
       ofile->setHeavyFlush();
       gridfiles_.emplace_back(std::move(ofile));
@@ -882,20 +1003,24 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   }
 
   log<<"  Bibliography "<<plumed.cite("Pfaendtner and Bonomi. J. Chem. Theory Comput. 11, 5062 (2015)");
-  if(doInt_[0]) log<<plumed.cite(
-                       "Baftizadeh, Cossio, Pietrucci, and Laio, Curr. Phys. Chem. 2, 79 (2012)");
-  if(mw_n_>1||walkers_mpi_) log<<plumed.cite(
-                                   "Raiteri, Laio, Gervasio, Micheletti, and Parrinello, J. Phys. Chem. B 110, 3533 (2006)");
-  if(adaptive_!=FlexibleBin::none) log<<plumed.cite(
-                                          "Branduardi, Bussi, and Parrinello, J. Chem. Theory Comput. 8, 2247 (2012)");
-  if (do_pf_) log<<plumed.cite("Prakash, Fu, Bonomi, and Pfaendtner, J. Chem. Theory Comput. 14, 4985 (2018)");
+  if(doInt_[0])
+    log<<plumed.cite(
+         "Baftizadeh, Cossio, Pietrucci, and Laio, Curr. Phys. Chem. 2, 79 (2012)");
+  if(mw_n_>1||walkers_mpi_)
+    log<<plumed.cite(
+         "Raiteri, Laio, Gervasio, Micheletti, and Parrinello, J. Phys. Chem. B 110, 3533 (2006)");
+  if(adaptive_!=FlexibleBin::none)
+    log<<plumed.cite(
+         "Branduardi, Bussi, and Parrinello, J. Chem. Theory Comput. 8, 2247 (2012)");
+  if (do_pf_) {
+    log<<plumed.cite("Prakash, Fu, Bonomi, and Pfaendtner, J. Chem. Theory Comput. 14, 4985 (2018)");
+  }
   log<<"\n";
 
 
 }
 
-void PBMetaD::readGaussians(unsigned iarg, IFile *ifile)
-{
+void PBMetaD::readGaussians(unsigned iarg, IFile *ifile) {
   std::vector<double> center(1);
   std::vector<double> sigma(1);
   double height;
@@ -909,14 +1034,15 @@ void PBMetaD::readGaussians(unsigned iarg, IFile *ifile)
   while(scanOneHill(iarg,ifile,tmpvalues,center,sigma,height,multivariate)) {
     ;
     nhills++;
-    if(welltemp_) {height*=(biasf_-1.0)/biasf_;}
+    if(welltemp_) {
+      height*=(biasf_-1.0)/biasf_;
+    }
     addGaussian(family, Gaussian(center,sigma,height,multivariate));
   }
   log.printf("      %d Gaussians read\n",nhills);
 }
 
-void PBMetaD::writeGaussian(unsigned iarg, const Gaussian& hill, OFile *ofile)
-{
+void PBMetaD::writeGaussian(unsigned iarg, const Gaussian& hill, OFile *ofile) {
   int family=pfs_[iarg];
   ofile->printField("time",getTimeStep()*getStep());
   ofile->printField(pfhold_[family],hill.center[0]);
@@ -932,17 +1058,21 @@ void PBMetaD::writeGaussian(unsigned iarg, const Gaussian& hill, OFile *ofile)
     ofile->printField("sigma_"+pfhold_[family]->getName(),hill.sigma[0]);
   }
   double height=hill.height;
-  if(welltemp_) height *= biasf_/(biasf_-1.0);
+  if(welltemp_) {
+    height *= biasf_/(biasf_-1.0);
+  }
   ofile->printField("height",height);
   ofile->printField("biasf",biasf_);
-  if(mw_n_>1) ofile->printField("clock",int(std::time(0)));
+  if(mw_n_>1) {
+    ofile->printField("clock",int(std::time(0)));
+  }
   ofile->printField();
 }
 
-void PBMetaD::addGaussian(unsigned iarg, const Gaussian& hill)
-{
-  if(!grid_) {hills_[iarg].push_back(hill);}
-  else {
+void PBMetaD::addGaussian(unsigned iarg, const Gaussian& hill) {
+  if(!grid_) {
+    hills_[iarg].push_back(hill);
+  } else {
     std::vector<unsigned> nneighb=getGaussianSupport(iarg, hill);
     std::vector<Grid::index_t> neighbors=BiasGrids_[iarg]->getNeighbors(hill.center,nneighb);
     std::vector<double> der(1);
@@ -976,8 +1106,7 @@ void PBMetaD::addGaussian(unsigned iarg, const Gaussian& hill)
   }
 }
 
-std::vector<unsigned> PBMetaD::getGaussianSupport(unsigned iarg, const Gaussian& hill)
-{
+std::vector<unsigned> PBMetaD::getGaussianSupport(unsigned iarg, const Gaussian& hill) {
   std::vector<unsigned> nneigh;
   double cutoff;
   if(hill.multivariate) {
@@ -1002,8 +1131,7 @@ std::vector<unsigned> PBMetaD::getGaussianSupport(unsigned iarg, const Gaussian&
   return nneigh;
 }
 
-double PBMetaD::getBiasAndDerivatives(unsigned iarg, const std::vector<double>& cv, double* der)
-{
+double PBMetaD::getBiasAndDerivatives(unsigned iarg, const std::vector<double>& cv, double* der) {
   double bias=0.0;
   int family = pfs_[iarg];
   if(!grid_) {
@@ -1013,7 +1141,9 @@ double PBMetaD::getBiasAndDerivatives(unsigned iarg, const std::vector<double>&
       bias += evaluateGaussian(iarg,cv,hills_[family][i],der);
     }
     comm.Sum(bias);
-    if(der) comm.Sum(der,1);
+    if(der) {
+      comm.Sum(der,1);
+    }
   } else {
     if(der) {
       std::vector<double> vder(1);
@@ -1027,8 +1157,7 @@ double PBMetaD::getBiasAndDerivatives(unsigned iarg, const std::vector<double>&
   return bias;
 }
 
-double PBMetaD::evaluateGaussian(unsigned iarg, const std::vector<double>& cv, const Gaussian& hill, double* der)
-{
+double PBMetaD::evaluateGaussian(unsigned iarg, const std::vector<double>& cv, const Gaussian& hill, double* der) {
   double bias=0.0;
 // I use a pointer here because cv is const (and should be const)
 // but when using doInt it is easier to locally replace cv[0] with
@@ -1038,8 +1167,13 @@ double PBMetaD::evaluateGaussian(unsigned iarg, const std::vector<double>& cv, c
   tmpcv[0]=cv[0];
   bool isOutOfInt = false;
   if(doInt_[iarg]) {
-    if(cv[0]<lowI_[iarg]) { tmpcv[0]=lowI_[iarg]; isOutOfInt = true; }
-    else if(cv[0]>uppI_[iarg]) { tmpcv[0]=uppI_[iarg]; isOutOfInt = true; }
+    if(cv[0]<lowI_[iarg]) {
+      tmpcv[0]=lowI_[iarg];
+      isOutOfInt = true;
+    } else if(cv[0]>uppI_[iarg]) {
+      tmpcv[0]=uppI_[iarg];
+      isOutOfInt = true;
+    }
   }
   pcv=&(tmpcv[0]);
 
@@ -1068,11 +1202,12 @@ double PBMetaD::evaluateGaussian(unsigned iarg, const std::vector<double>& cv, c
   return bias;
 }
 
-void PBMetaD::calculate()
-{
+void PBMetaD::calculate() {
   // this is because presently there is no way to properly pass information
   // on adaptive hills (diff) after exchanges:
-  if(adaptive_==FlexibleBin::diffusion && getExchangeStep()) error("ADAPTIVE=DIFF is not compatible with replica exchange");
+  if(adaptive_==FlexibleBin::diffusion && getExchangeStep()) {
+    error("ADAPTIVE=DIFF is not compatible with replica exchange");
+  }
 
   std::vector<double> cv(1);
   double der[1];
@@ -1086,7 +1221,9 @@ void PBMetaD::calculate()
     der[0]   = 0.0;
     bias[i]  = getBiasAndDerivatives(i, cv, der);
     deriv[i] = der[0];
-    if(bias[i] < bmin) bmin = bias[i];
+    if(bias[i] < bmin) {
+      bmin = bias[i];
+    }
   }
   double ene = 0.;
   for(unsigned i=0; i<getNumberOfArguments(); ++i) {
@@ -1094,7 +1231,9 @@ void PBMetaD::calculate()
   }
 
   // set Forces - set them to zero if SELECTOR is active
-  if(do_select_) current_value_ = static_cast<unsigned>(plumed.passMap[selector_]);
+  if(do_select_) {
+    current_value_ = static_cast<unsigned>(plumed.passMap[selector_]);
+  }
 
   if(!do_select_ || select_value_==current_value_) {
     for(unsigned i=0; i<getNumberOfArguments(); ++i) {
@@ -1104,7 +1243,9 @@ void PBMetaD::calculate()
   }
 
   if(do_select_ && select_value_!=current_value_) {
-    for(unsigned i=0; i<getNumberOfArguments(); ++i) setOutputForce(i, 0.0);
+    for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+      setOutputForce(i, 0.0);
+    }
   }
 
   // set bias
@@ -1112,20 +1253,22 @@ void PBMetaD::calculate()
   setBias(ene);
 }
 
-void PBMetaD::update()
-{
+void PBMetaD::update() {
   bool multivariate;
   // adding hills criteria
   bool nowAddAHill;
-  if(getStep()%stride_==0 && !isFirstStep_) nowAddAHill=true;
-  else {
+  if(getStep()%stride_==0 && !isFirstStep_) {
+    nowAddAHill=true;
+  } else {
     nowAddAHill=false;
     isFirstStep_=false;
   }
 
   // if you use adaptive, call the FlexibleBin
   if(adaptive_!=FlexibleBin::none) {
-    for(unsigned i=0; i<getNumberOfArguments(); i++) flexbin_[i].update(nowAddAHill,i);
+    for(unsigned i=0; i<getNumberOfArguments(); i++) {
+      flexbin_[i].update(nowAddAHill,i);
+    }
     multivariate=true;
   } else {
     multivariate=false;
@@ -1144,12 +1287,17 @@ void PBMetaD::update()
     for(unsigned i=0; i<getNumberOfArguments(); ++i) {
       int family=pfs_[i];
       // get flex/sigmas for each family and assign them to this args sigma
-      if(adaptive_!=FlexibleBin::none) thissigma[i]=flexbin_[family].getInverseMatrix(i)[0];
-      else thissigma[i]=sigma0_[family];
+      if(adaptive_!=FlexibleBin::none) {
+        thissigma[i]=flexbin_[family].getInverseMatrix(i)[0];
+      } else {
+        thissigma[i]=sigma0_[family];
+      }
       cv[i]     = getArgument(i);
       cv_tmp[0] = getArgument(i);
       bias[i] = getBiasAndDerivatives(i, cv_tmp);
-      if(bias[i] < bmin) bmin = bias[i];
+      if(bias[i] < bmin) {
+        bmin = bias[i];
+      }
     }
     // calculate heights and norm
     for(unsigned i=0; i<getNumberOfArguments(); ++i) {
@@ -1160,7 +1308,9 @@ void PBMetaD::update()
     // normalize and apply welltemp correction
     for(unsigned i=0; i<getNumberOfArguments(); ++i) {
       height[i] *=  height0_ / norm;
-      if(welltemp_) height[i] *= std::exp(-bias[i]/(kbt_*(biasf_-1.0)));
+      if(welltemp_) {
+        height[i] *= std::exp(-bias[i]/(kbt_*(biasf_-1.0)));
+      }
     }
 
     // MPI Multiple walkers: share hills and add them all
@@ -1205,8 +1355,11 @@ void PBMetaD::update()
         // Add CVs of same family together and write to same file
         int family = pfs_[i];
         cv_tmp[0] = cv[i];
-        if(adaptive_!=FlexibleBin::none) sigma_tmp[0]=thissigma[i];
-        else sigma_tmp[0] = sigma0_[family];
+        if(adaptive_!=FlexibleBin::none) {
+          sigma_tmp[0]=thissigma[i];
+        } else {
+          sigma_tmp[0] = sigma0_[family];
+        }
         Gaussian newhill = Gaussian(cv_tmp, sigma_tmp, height[i], multivariate);
         addGaussian(family, newhill);
         writeGaussian(i, newhill, hillsOfiles_[family].get());
@@ -1218,7 +1371,9 @@ void PBMetaD::update()
   if(wgridstride_>0 && (getStep()%wgridstride_==0 || getCPT())) {
     int r = 0;
     if(walkers_mpi_) {
-      if(comm.Get_rank()==0) r=multi_sim_comm.Get_rank();
+      if(comm.Get_rank()==0) {
+        r=multi_sim_comm.Get_rank();
+      }
       comm.Bcast(r,0);
     }
     if(r==0) {
@@ -1236,7 +1391,9 @@ void PBMetaD::update()
       for(unsigned i=0; i<hillsfname_.size(); ++i) {
         unsigned k=j*hillsfname_.size()+i;
         // don't read your own Gaussians
-        if(j==mw_id_) continue;
+        if(j==mw_id_) {
+          continue;
+        }
         // if the file is not open yet
         if(!(ifiles_[k]->isOpen())) {
           // check if it exists now and open it!
@@ -1257,8 +1414,7 @@ void PBMetaD::update()
 }
 
 /// takes a pointer to the file and a template string with values v and gives back the next center, sigma and height
-bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpvalues, std::vector<double> &center, std::vector<double> &sigma, double &height, bool &multivariate)
-{
+bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpvalues, std::vector<double> &center, std::vector<double> &sigma, double &height, bool &multivariate) {
   double dummy;
   multivariate=false;
   Value* argPtr = pfhold_[pfs_[iarg]];
@@ -1267,15 +1423,19 @@ bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpva
     if( tmpvalues[0].isPeriodic() && ! argPtr->isPeriodic() ) {
       error("in hills file periodicity for variable " + tmpvalues[0].getName() + " does not match periodicity in input");
     } else if( tmpvalues[0].isPeriodic() ) {
-      std::string imin, imax; tmpvalues[0].getDomain( imin, imax );
-      std::string rmin, rmax; argPtr->getDomain( rmin, rmax );
+      std::string imin, imax;
+      tmpvalues[0].getDomain( imin, imax );
+      std::string rmin, rmax;
+      argPtr->getDomain( rmin, rmax );
       if( imin!=rmin || imax!=rmax ) {
         error("in hills file periodicity for variable " + tmpvalues[0].getName() + " does not match periodicity in input");
       }
     }
     center[0]=tmpvalues[0].get();
     std::string ktype="stretched-gaussian";
-    if( ifile->FieldExist("kerneltype") ) ifile->scanField("kerneltype",ktype);
+    if( ifile->FieldExist("kerneltype") ) {
+      ifile->scanField("kerneltype",ktype);
+    }
 
     if( ktype=="gaussian" ) {
       noStretchWarning();
@@ -1285,9 +1445,13 @@ bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpva
 
     std::string sss;
     ifile->scanField("multivariate",sss);
-    if(sss=="true") multivariate=true;
-    else if(sss=="false") multivariate=false;
-    else plumed_merror("cannot parse multivariate = "+ sss);
+    if(sss=="true") {
+      multivariate=true;
+    } else if(sss=="false") {
+      multivariate=false;
+    } else {
+      plumed_merror("cannot parse multivariate = "+ sss);
+    }
     if(multivariate) {
       ifile->scanField("sigma_"+argPtr->getName()+"_"+
                        argPtr->getName(),sigma[0]);
@@ -1297,9 +1461,15 @@ bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpva
     }
     ifile->scanField("height",height);
     ifile->scanField("biasf",dummy);
-    if(ifile->FieldExist("clock")) ifile->scanField("clock",dummy);
-    if(ifile->FieldExist("lower_int")) ifile->scanField("lower_int",dummy);
-    if(ifile->FieldExist("upper_int")) ifile->scanField("upper_int",dummy);
+    if(ifile->FieldExist("clock")) {
+      ifile->scanField("clock",dummy);
+    }
+    if(ifile->FieldExist("lower_int")) {
+      ifile->scanField("lower_int",dummy);
+    }
+    if(ifile->FieldExist("upper_int")) {
+      ifile->scanField("upper_int",dummy);
+    }
     ifile->scanField();
     return true;
   } else {
@@ -1308,12 +1478,16 @@ bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpva
 
 }
 
-bool PBMetaD::checkNeedsGradients()const
-{
+bool PBMetaD::checkNeedsGradients()const {
   if(adaptive_==FlexibleBin::geometry) {
-    if(getStep()%stride_==0 && !isFirstStep_) return true;
-    else return false;
-  } else return false;
+    if(getStep()%stride_==0 && !isFirstStep_) {
+      return true;
+    } else {
+      return false;
+    }
+  } else {
+    return false;
+  }
 }
 
 }
