@@ -20,8 +20,6 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "core/ActionRegister.h"
-#include "core/PlumedMain.h"
-#include "core/Atoms.h"
 #include "ReweightBase.h"
 
 //+PLUMEDOC REWEIGHTING REWEIGHT_TEMP_PRESS
@@ -197,12 +195,12 @@ void ReweightTemperaturePressure::registerKeywords(Keywords& keys ) {
   keys.add("optional","REWEIGHT_PRESSURE","Reweighting pressure");
   keys.add("optional","PRESSURE","The system pressure");
   keys.add("optional","REWEIGHT_TEMP","Reweighting temperature");
+  keys.setValueDescription("the weight to use for this frame to determine its contribution at a different temperature/pressure");
 }
 
 ReweightTemperaturePressure::ReweightTemperaturePressure(const ActionOptions&ao):
   Action(ao),
-  ReweightBase(ao)
-{
+  ReweightBase(ao) {
   // Initialize to not defined (negative)
   rpress_=-1;
   press_=-1;
@@ -210,12 +208,14 @@ ReweightTemperaturePressure::ReweightTemperaturePressure(const ActionOptions&ao)
   parse("REWEIGHT_PRESSURE",rpress_);
   parse("PRESSURE",press_);
   parse("REWEIGHT_TEMP",rtemp_);
-  rtemp_*=plumed.getAtoms().getKBoltzmann();
+  rtemp_*=getKBoltzmann();
 
   parseArgumentList("ENERGY",myenergy);
   if(!myenergy.empty()) {
     log.printf("  with energies: ");
-    for(unsigned i=0; i<myenergy.size(); i++) log.printf(" %s",myenergy[i]->getName().c_str());
+    for(unsigned i=0; i<myenergy.size(); i++) {
+      log.printf(" %s",myenergy[i]->getName().c_str());
+    }
     log.printf("\n");
   }
   //requestArguments(myenergy);
@@ -223,7 +223,9 @@ ReweightTemperaturePressure::ReweightTemperaturePressure(const ActionOptions&ao)
   parseArgumentList("VOLUME",myvol);
   if(!myvol.empty()) {
     log.printf("  with volumes: ");
-    for(unsigned i=0; i<myvol.size(); i++) log.printf(" %s",myvol[i]->getName().c_str());
+    for(unsigned i=0; i<myvol.size(); i++) {
+      log.printf(" %s",myvol[i]->getName().c_str());
+    }
     log.printf("\n");
   }
 
@@ -235,31 +237,53 @@ ReweightTemperaturePressure::ReweightTemperaturePressure(const ActionOptions&ao)
   // 4 possible cases
   // Case 1) Reweight from T to T' with V=const (canonical)
   if (rtemp_>=0 && press_<0 && rpress_<0 && !myenergy.empty() && myvol.empty() ) {
-    log.printf("  reweighting simulation from temperature %f to temperature %f at constant volume \n",simtemp/plumed.getAtoms().getKBoltzmann(),rtemp_/plumed.getAtoms().getKBoltzmann() );
+    log.printf("  reweighting simulation from temperature %f to temperature %f at constant volume \n",simtemp/getKBoltzmann(),rtemp_/getKBoltzmann() );
     log.printf("  WARNING: If the simulation is performed at constant pressure add the keywords PRESSURE and VOLUME \n" );
   }
   // Case 2) Reweight from T to T' with P=const (isothermal-isobaric)
-  else if (rtemp_>=0 && press_>=0 && rpress_<0 && !myenergy.empty() && !myvol.empty() ) log.printf("  reweighting simulation from temperature %f to temperature %f at constant pressure %f \n",simtemp/plumed.getAtoms().getKBoltzmann(),rtemp_/plumed.getAtoms().getKBoltzmann(), press_ );
+  else if (rtemp_>=0 && press_>=0 && rpress_<0 && !myenergy.empty() && !myvol.empty() ) {
+    log.printf("  reweighting simulation from temperature %f to temperature %f at constant pressure %f \n",simtemp/getKBoltzmann(),rtemp_/getKBoltzmann(), press_ );
+  }
   // Case 3) Reweight from P to P' with T=const (isothermal-isobaric)
-  else if (rtemp_<0 && press_>=0 && rpress_>=0 && myenergy.empty() && !myvol.empty() ) log.printf("  reweighting simulation from pressure %f to pressure %f at constant temperature %f\n",press_,rpress_,simtemp/plumed.getAtoms().getKBoltzmann() );
+  else if (rtemp_<0 && press_>=0 && rpress_>=0 && myenergy.empty() && !myvol.empty() ) {
+    log.printf("  reweighting simulation from pressure %f to pressure %f at constant temperature %f\n",press_,rpress_,simtemp/getKBoltzmann() );
+  }
   // Case 4) Reweight from T,P to T',P' (isothermal-isobaric)
-  else if (rtemp_>0 && press_>=0 && rpress_>=0 && !myenergy.empty() && !myvol.empty() ) log.printf("  reweighting simulation from temperature %f and pressure %f to temperature %f and pressure %f \n",simtemp/plumed.getAtoms().getKBoltzmann(), press_, rtemp_/plumed.getAtoms().getKBoltzmann(), rpress_);
-  else error("Combination of ENERGY, VOLUME, REWEIGHT_PRESSURE, PRESSURE and REWEIGHT_TEMP not supported. Please refer to the manual for supported combinations.");
+  else if (rtemp_>0 && press_>=0 && rpress_>=0 && !myenergy.empty() && !myvol.empty() ) {
+    log.printf("  reweighting simulation from temperature %f and pressure %f to temperature %f and pressure %f \n",simtemp/getKBoltzmann(), press_, rtemp_/getKBoltzmann(), rpress_);
+  } else {
+    error("Combination of ENERGY, VOLUME, REWEIGHT_PRESSURE, PRESSURE and REWEIGHT_TEMP not supported. Please refer to the manual for supported combinations.");
+  }
 }
 
 double ReweightTemperaturePressure::getLogWeight() {
-  double energy=0.0; for(unsigned i=0; i<myenergy.size(); ++i) energy+=getArgument(i);
-  double volume=0.0; for(unsigned i=0; i<myvol.size(); ++i) volume+=getArgument(myenergy.size()+i);
+  double energy=0.0;
+  for(unsigned i=0; i<myenergy.size(); ++i) {
+    energy+=getArgument(i);
+  }
+  double volume=0.0;
+  for(unsigned i=0; i<myvol.size(); ++i) {
+    volume+=getArgument(myenergy.size()+i);
+  }
   // 4 possible cases
   // Case 1) Reweight from T to T' with V=const (canonical)
-  if (rtemp_>=0 && press_<0 && rpress_<0) return ((1.0/simtemp)- (1.0/rtemp_) )*energy;
+  if (rtemp_>=0 && press_<0 && rpress_<0) {
+    return ((1.0/simtemp)- (1.0/rtemp_) )*energy;
+  }
   // Case 2) Reweight from T to T' with P=const (isothermal-isobaric)
-  else if (rtemp_>=0 && press_>=0 && rpress_<0)  return ((1.0/simtemp)- (1.0/rtemp_) )*energy + ((1.0/simtemp) - (1.0/rtemp_))*press_*volume;
+  else if (rtemp_>=0 && press_>=0 && rpress_<0) {
+    return ((1.0/simtemp)- (1.0/rtemp_) )*energy + ((1.0/simtemp) - (1.0/rtemp_))*press_*volume;
+  }
   // Case 3) Reweight from P to P' with T=const (isothermal-isobaric)
-  else if (rtemp_<0 && press_>=0 && rpress_>=0)  return (1.0/simtemp)*(press_ - rpress_)*volume;
+  else if (rtemp_<0 && press_>=0 && rpress_>=0) {
+    return (1.0/simtemp)*(press_ - rpress_)*volume;
+  }
   // Case 4) Reweight from T,P to T',P' (isothermal-isobaric)
-  else if (rtemp_>0 && press_>=0 && rpress_>=0) return ((1.0/simtemp)- (1.0/rtemp_) )*energy + ((1.0/simtemp)*press_ - (1.0/rtemp_)*rpress_ )*volume;
-  else return 0;
+  else if (rtemp_>0 && press_>=0 && rpress_>=0) {
+    return ((1.0/simtemp)- (1.0/rtemp_) )*energy + ((1.0/simtemp)*press_ - (1.0/rtemp_)*rpress_ )*volume;
+  } else {
+    return 0;
+  }
 }
 
 }
