@@ -19,7 +19,7 @@ freely, subject to the following restrictions:
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 
 #include "Sasa.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "core/PlumedMain.h"
 #include "core/GenericMolInfo.h"
 #include "core/ActionSet.h"
@@ -169,6 +169,7 @@ void SASA_LCPO::registerKeywords(Keywords& keys) {
   keys.add("compulsory", "NL_STRIDE", "The frequency with which the neighbor list is updated.");
   keys.add("optional","DELTAGFILE","a file containing the free energy values for backbone and sidechains. Necessary only if TYPE = TRANSFER. A Python script for the computation of free energy of transfer values to describe the effect of osmolyte concentration, temperature and pressure is freely available at https://github.com/andrea-arsiccio/DeltaG-calculation. The script automatically outputs a DeltaG.dat file compatible with this SASA module. If TYPE = TRANSFER and no DELTAGFILE is provided, the free energy values are those describing the effect of temperature, and are computed using the temperature value passed by the MD engine");
   keys.add("optional","APPROACH","either approach 2 or 3. Necessary only if TYPE = TRANSFER and no DELTAGFILE is provided. If TYPE = TRANSFER and no DELTAGFILE is provided, the free energy values are those describing the effect of temperature, and the program must know if approach 2 or 3 (as described in Arsiccio and Shea, Protein Cold Denaturation in Implicit Solvent Simulations: A Transfer Free Energy Approach, J. Phys. Chem. B, 2021) needs to be used to compute them");
+  keys.setValueDescription("the solvent accessible surface area (SASA) of the molecule");
 }
 
 
@@ -179,32 +180,42 @@ SASA_LCPO::SASA_LCPO(const ActionOptions&ao):
   Ti(0),
   stride(10),
   nl_update(0),
-  firstStepFlag(0)
-{
+  firstStepFlag(0) {
   rs = 0.14;
   parse("DELTAGFILE",DeltaGValues);
   parse("APPROACH", approach);
   parseAtomList("ATOMS",atoms);
-  if(atoms.size()==0) error("no atoms specified");
+  if(atoms.size()==0) {
+    error("no atoms specified");
+  }
   std::string Type;
   parse("TYPE",Type);
   parse("NL_STRIDE", stride);
   parseFlag("NOPBC",nopbc);
   checkRead();
 
-  if(Type=="TOTAL") sasa_type=TOTAL;
-  else if(Type=="TRANSFER") sasa_type=TRANSFER;
-  else error("Unknown SASA type");
+  if(Type=="TOTAL") {
+    sasa_type=TOTAL;
+  } else if(Type=="TRANSFER") {
+    sasa_type=TRANSFER;
+  } else {
+    error("Unknown SASA type");
+  }
 
-  switch(sasa_type)
-  {
-  case TOTAL:   log.printf("  TOTAL SASA;"); break;
-  case TRANSFER: log.printf("  TRANSFER MODEL;"); break;
+  switch(sasa_type) {
+  case TOTAL:
+    log.printf("  TOTAL SASA;");
+    break;
+  case TRANSFER:
+    log.printf("  TRANSFER MODEL;");
+    break;
   }
 
   log.printf("  atoms involved : ");
   for(unsigned i=0; i<atoms.size(); ++i) {
-    if(i%25==0) log<<"\n";
+    if(i%25==0) {
+      log<<"\n";
+    }
     log.printf("%d ",atoms[i].serial());
   }
   log.printf("\n");
@@ -216,7 +227,8 @@ SASA_LCPO::SASA_LCPO(const ActionOptions&ao):
   }
 
 
-  addValueWithDerivatives(); setNotPeriodic();
+  addValueWithDerivatives();
+  setNotPeriodic();
   requestAtoms(atoms);
 
   natoms = getNumberOfAtoms();
@@ -232,8 +244,7 @@ SASA_LCPO::SASA_LCPO(const ActionOptions&ao):
 
 //splits strings into tokens. Used to read into LCPO parameters file and into reference pdb file
 template <class Container>
-void split(const std::string& str, Container& cont)
-{
+void split(const std::string& str, Container& cont) {
   std::istringstream iss(str);
   std::copy(std::istream_iterator<std::string>(iss),
             std::istream_iterator<std::string>(),
@@ -245,7 +256,9 @@ void split(const std::string& str, Container& cont)
 
 void SASA_LCPO::readPDB() {
   auto* moldat = plumed.getActionSet().selectLatest<GenericMolInfo*>(this);
-  if( ! moldat ) error("Unable to find MOLINFO in input");
+  if( ! moldat ) {
+    error("Unable to find MOLINFO in input");
+  }
   AtomResidueName[0].clear();
   AtomResidueName[1].clear();
 
@@ -552,9 +565,12 @@ void SASA_LCPO::readDeltaG() {
         }
       }
     }
-    if ( backboneflag == 0) error("Cannot find backbone value in Delta G parameters file\n");
+    if ( backboneflag == 0) {
+      error("Cannot find backbone value in Delta G parameters file\n");
+    }
+  } else {
+    error("Cannot open DeltaG file");
   }
-  else error("Cannot open DeltaG file");
 
   for(unsigned i=0; i<natoms; i++) {
     if (DeltaG[i].size()==0 ) {
@@ -574,7 +590,7 @@ void SASA_LCPO::computeDeltaG() {
   }
 
   double T;
-  T = plumed.getAtoms().getKbT()/plumed.getAtoms().getKBoltzmann();
+  T = getkBT()/getKBoltzmann();
 
   if (T != Ti) {
     for(unsigned i=0; i<natoms; i++) {
@@ -725,7 +741,9 @@ void SASA_LCPO::computeDeltaG() {
 
 //calculates neighbor list
 void SASA_LCPO::calcNlist() {
-  if(!nopbc) makeWhole();
+  if(!nopbc) {
+    makeWhole();
+  }
 
   for(unsigned i = 0; i < natoms; i++) {
     Nlist[i].clear();
@@ -751,9 +769,13 @@ void SASA_LCPO::calcNlist() {
 
 //calculates SASA according to LCPO algorithm
 void SASA_LCPO::calculate() {
-  if(!nopbc) makeWhole();
+  if(!nopbc) {
+    makeWhole();
+  }
 
-  if(getExchangeStep()) nl_update = 0;
+  if(getExchangeStep()) {
+    nl_update = 0;
+  }
   if (firstStepFlag ==0) {
     readPDB();
     readLCPOparam();
@@ -893,7 +915,9 @@ void SASA_LCPO::calculate() {
 
           }
           double sasai = (LCPOparam[i][1]*S1+LCPOparam[i][2]*Aij+LCPOparam[i][3]*Ajk+LCPOparam[i][4]*Aijk);
-          if (sasai > 0 ) sasa += sasai/100;
+          if (sasai > 0 ) {
+            sasa += sasai/100;
+          }
           derivatives[i][0] += (dAijdc_2[0]*LCPOparam[i][2]+dAijdc_4[0]*LCPOparam[i][4])/10;
           derivatives[i][1] += (dAijdc_2[1]*LCPOparam[i][2]+dAijdc_4[1]*LCPOparam[i][4])/10;
           derivatives[i][2] += (dAijdc_2[2]*LCPOparam[i][2]+dAijdc_4[2]*LCPOparam[i][4])/10;
@@ -1046,14 +1070,18 @@ void SASA_LCPO::calculate() {
           double sasai = (LCPOparam[i][1]*S1+LCPOparam[i][2]*Aij+LCPOparam[i][3]*Ajk+LCPOparam[i][4]*Aijk);
 
           if (AtomResidueName[0][i] == "N" || AtomResidueName[0][i] == "CA"  || AtomResidueName[0][i] == "C" || AtomResidueName[0][i] == "O") {
-            if (sasai > 0 ) sasa += (sasai/MaxSurf[i][0]*DeltaG[natoms][0]);
+            if (sasai > 0 ) {
+              sasa += (sasai/MaxSurf[i][0]*DeltaG[natoms][0]);
+            }
             derivatives[i][0] += ((dAijdc_2[0]*LCPOparam[i][2]+dAijdc_4[0]*LCPOparam[i][4])/MaxSurf[i][0]*DeltaG[natoms][0])*10;
             derivatives[i][1] += ((dAijdc_2[1]*LCPOparam[i][2]+dAijdc_4[1]*LCPOparam[i][4])/MaxSurf[i][0]*DeltaG[natoms][0])*10;
             derivatives[i][2] += ((dAijdc_2[2]*LCPOparam[i][2]+dAijdc_4[2]*LCPOparam[i][4])/MaxSurf[i][0]*DeltaG[natoms][0])*10;
           }
 
           if (AtomResidueName[0][i] != "N" && AtomResidueName[0][i] != "CA"  && AtomResidueName[0][i] != "C" && AtomResidueName[0][i] != "O") {
-            if (sasai > 0. ) sasa += (sasai/MaxSurf[i][1]*DeltaG[i][0]);
+            if (sasai > 0. ) {
+              sasa += (sasai/MaxSurf[i][1]*DeltaG[i][0]);
+            }
             derivatives[i][0] += ((dAijdc_2[0]*LCPOparam[i][2]+dAijdc_4[0]*LCPOparam[i][4])/MaxSurf[i][1]*DeltaG[i][0])*10;
             derivatives[i][1] += ((dAijdc_2[1]*LCPOparam[i][2]+dAijdc_4[1]*LCPOparam[i][4])/MaxSurf[i][1]*DeltaG[i][0])*10;
             derivatives[i][2] += ((dAijdc_2[2]*LCPOparam[i][2]+dAijdc_4[2]*LCPOparam[i][4])/MaxSurf[i][1]*DeltaG[i][0])*10;
@@ -1065,7 +1093,9 @@ void SASA_LCPO::calculate() {
   }
 
 
-  for(unsigned i=0; i<natoms; i++) { setAtomsDerivatives(i,derivatives[i]);}
+  for(unsigned i=0; i<natoms; i++) {
+    setAtomsDerivatives(i,derivatives[i]);
+  }
   setBoxDerivatives(virial);
   setValue(sasa);
   firstStepFlag = 1;
